"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.IconButtonArray = exports.IconButtonArrayComponent = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
/**
 *
 *  Copyright (c) "Neo4j"
 *  Neo4j Sweden AB [http://neo4j.com]
 *
 *  This file is part of Neo4j.
 *
 *  Neo4j is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
const react_1 = __importDefault(require("react"));
const defaultImports_1 = require("../_common/defaultImports");
const icons_1 = require("../icons");
const IconButton_1 = require("./IconButton");
const CollapsibleButtonWrapper = ({ children, }) => {
    return (0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: children });
};
CollapsibleButtonWrapper.displayName = 'CollapsibleButtonWrapper';
exports.IconButtonArrayComponent = react_1.default.forwardRef(function IconButtonArrayComponent({ children, as, isFloating = false, orientation = 'horizontal', size = 'medium', className, style, htmlAttributes, }, ref) {
    const [isCollapsed, setIsCollapsed] = react_1.default.useState(true);
    const classes = (0, defaultImports_1.classNames)('ndl-icon-btn-array', {
        'n-flex-row': orientation === 'horizontal',
        'n-flex-col': orientation === 'vertical',
        'ndl-array-floating': isFloating,
        [`ndl-${size}`]: size,
        [className]: className,
    });
    const Component = as || 'div';
    const applySizeProp = (child) => {
        if (react_1.default.isValidElement(child) &&
            child.type === IconButton_1.IconButton) {
            return react_1.default.cloneElement(child, { size: child.props.size || size });
        }
        return child;
    };
    const childrenArray = react_1.default.Children.toArray(children);
    const fixedButtons = childrenArray.filter((child) => !react_1.default.isValidElement(child) ||
        child.type.displayName !==
            'CollapsibleButtonWrapper');
    const fixedButtonsWithProps = react_1.default.Children.map(fixedButtons, applySizeProp);
    const collapsibleButtonWrapper = childrenArray.find((child) => react_1.default.isValidElement(child) &&
        child.type.displayName ===
            'CollapsibleButtonWrapper');
    const collapsibleButtonsWithProps = collapsibleButtonWrapper
        ? react_1.default.Children.map(collapsibleButtonWrapper.props.children, applySizeProp)
        : null;
    const renderChevronIcon = () => {
        if (orientation === 'horizontal') {
            return isCollapsed ? ((0, jsx_runtime_1.jsx)(icons_1.ChevronRightIconOutline, {})) : ((0, jsx_runtime_1.jsx)(icons_1.ChevronLeftIconOutline, {}));
        }
        return isCollapsed ? (0, jsx_runtime_1.jsx)(icons_1.ChevronDownIconOutline, {}) : (0, jsx_runtime_1.jsx)(icons_1.ChevronUpIconOutline, {});
    };
    return ((0, jsx_runtime_1.jsxs)(Component, Object.assign({ role: "group", className: classes, ref: ref, style: style }, htmlAttributes, { children: [fixedButtonsWithProps, collapsibleButtonsWithProps && ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [!isCollapsed && collapsibleButtonsWithProps, (0, jsx_runtime_1.jsx)(IconButton_1.IconButton, { onClick: () => setIsCollapsed(!isCollapsed), size: size, ariaLabel: "Show more", "aria-expanded": !isCollapsed, isClean: true, isGrouped: true, children: renderChevronIcon() })] }))] })));
});
const IconButtonArray = Object.assign(exports.IconButtonArrayComponent, {
    CollapsibleButtonWrapper,
});
exports.IconButtonArray = IconButtonArray;
IconButtonArray.displayName = 'IconButtonArray';
//# sourceMappingURL=IconButtonArray.js.map