"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
/**
 *
 *  Copyright (c) "Neo4j"
 *  Neo4j Sweden AB [http://neo4j.com]
 *
 *  This file is part of Neo4j.
 *
 *  Neo4j is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/* eslint-disable no-irregular-whitespace */
const react_1 = require("@testing-library/react");
const vitest_1 = require("vitest");
const clickable_urls_1 = require("./clickable-urls");
(0, vitest_1.describe)('clickable-urls', () => {
    (0, vitest_1.describe)('convertUrlsToHrefTags', () => {
        (0, vitest_1.test)('handles most common URL formats', () => {
            const urls = [
                'bolt://127.0.0.1:7687',
                'http://foo.com',
                'http://goo.gl',
                'https://foo.com',
                'https://www.foo.com',
                'https://www.foo.com/',
                'https://www.foo.com/bar',
                'http://goo.gl/1',
                'http://goo.gl/2',
                'http://firstround.com/review/thoughts-on-gender-and-radical-candor/?ct=t(How_Does_Your_Leadership_Team_Rate_12_3_2015)',
                'https://google.com',
                'http://www.cool.com.au',
                'http://www.cool.com.au/ersdfs',
                'http://www.cool.com.au/ersdfs?dfd=dfgd@s=1',
                'http://www.cool.com:81/index.html',
            ];
            const expected = urls.map((url) => `
        <div>
          <span>
            
            <a
              href="${url}"
              rel="noreferrer"
              target="_blank"
            >
              ${url}
            </a>
            
          </span>
        </div>
      `);
            urls.forEach((url, index) => (0, vitest_1.expect)((0, react_1.render)((0, jsx_runtime_1.jsx)(clickable_urls_1.ClickableUrls, { text: url })).container).toMatchInlineSnapshot(expected[index]));
        });
        (0, vitest_1.test)('does not catch invalid or missing protocol urls', () => {
            (0, vitest_1.expect)((0, react_1.render)((0, jsx_runtime_1.jsx)(clickable_urls_1.ClickableUrls, { text: "google.com" })).container)
                .toMatchInlineSnapshot(`
        <div>
          <span>
            google.com
          </span>
        </div>
      `);
            (0, vitest_1.expect)((0, react_1.render)((0, jsx_runtime_1.jsx)(clickable_urls_1.ClickableUrls, { text: "https:google.com" })).container)
                .toMatchInlineSnapshot(`
        <div>
          <span>
            https:google.com
          </span>
        </div>
      `);
        });
        (0, vitest_1.test)('handles urls inside parentheses', () => {
            (0, vitest_1.expect)((0, react_1.render)((0, jsx_runtime_1.jsx)(clickable_urls_1.ClickableUrls, { text: "(http://goo.gl/1)" })).container)
                .toMatchInlineSnapshot(`
        <div>
          <span>
            (
            <a
              href="http://goo.gl/1"
              rel="noreferrer"
              target="_blank"
            >
              http://goo.gl/1
            </a>
            )
          </span>
        </div>
      `);
        });
        (0, vitest_1.test)('does not include punctuation, comma, exclamation', () => {
            (0, vitest_1.expect)((0, react_1.render)((0, jsx_runtime_1.jsx)(clickable_urls_1.ClickableUrls, { text: "http://foo.com/." })).container)
                .toMatchInlineSnapshot(`
        <div>
          <span>
            
            <a
              href="http://foo.com/"
              rel="noreferrer"
              target="_blank"
            >
              http://foo.com/
            </a>
            .
          </span>
        </div>
      `);
            (0, vitest_1.expect)((0, react_1.render)((0, jsx_runtime_1.jsx)(clickable_urls_1.ClickableUrls, { text: "http://foo.com/!" })).container)
                .toMatchInlineSnapshot(`
        <div>
          <span>
            
            <a
              href="http://foo.com/"
              rel="noreferrer"
              target="_blank"
            >
              http://foo.com/
            </a>
            !
          </span>
        </div>
      `);
            (0, vitest_1.expect)((0, react_1.render)((0, jsx_runtime_1.jsx)(clickable_urls_1.ClickableUrls, { text: "http://foo.com/," })).container)
                .toMatchInlineSnapshot(`
        <div>
          <span>
            
            <a
              href="http://foo.com/"
              rel="noreferrer"
              target="_blank"
            >
              http://foo.com/
            </a>
            ,
          </span>
        </div>
      `);
        });
        (0, vitest_1.test)('Handles multiple URLs, even if in a text block', () => {
            const URLs = 'sftp://foo.se is better than ftp://bar.dk';
            const textBlock = `
Long black tulips, born in your blue tints
Lemongrass eyelids, smoke in your slick lips
(${URLs})
Chocolate chapstick, backbeat strat flips
Swimming pool spaceships, light through the wave tips
      `;
            const { container } = (0, react_1.render)((0, jsx_runtime_1.jsx)(clickable_urls_1.ClickableUrls, { text: textBlock }));
            (0, vitest_1.expect)(container).toMatchInlineSnapshot(`
        <div>
          <span>
            
        Long black tulips, born in your blue tints
        Lemongrass eyelids, smoke in your slick lips
        (
            <a
              href="sftp://foo.se"
              rel="noreferrer"
              target="_blank"
            >
              sftp://foo.se
            </a>
             is better than 
            <a
              href="ftp://bar.dk"
              rel="noreferrer"
              target="_blank"
            >
              ftp://bar.dk
            </a>
            )
        Chocolate chapstick, backbeat strat flips
        Swimming pool spaceships, light through the wave tips
              
          </span>
        </div>
      `);
        });
    });
    (0, vitest_1.describe)('ClickableUrls', () => {
        (0, vitest_1.it)('renders escaped HTML except for generated tags', () => {
            const text = `Hello, my <strong>name</strong> is <a href="http://twitter.com/neo4j" onClick="alert(1)">Neo4j</a>.`;
            const { container } = (0, react_1.render)((0, jsx_runtime_1.jsx)(clickable_urls_1.ClickableUrls, { text: text }));
            (0, vitest_1.expect)(container).toMatchInlineSnapshot(`
        <div>
          <span>
            Hello, my &lt;strong&gt;name&lt;/strong&gt; is &lt;a href="
            <a
              href="http://twitter.com/neo4j"
              rel="noreferrer"
              target="_blank"
            >
              http://twitter.com/neo4j
            </a>
            " onClick="alert(1)"&gt;Neo4j&lt;/a&gt;.
          </span>
        </div>
      `);
        });
    });
});
//# sourceMappingURL=clickable-urls-test.js.map