import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
/**
 *
 *  Copyright (c) "Neo4j"
 *  Neo4j Sweden AB [http://neo4j.com]
 *
 *  This file is part of Neo4j.
 *
 *  Neo4j is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
import React from 'react';
import { classNames } from '../_common/defaultImports';
import { BeakerIconOutline, ExclamationTriangleIconOutline, InformationCircleIconOutline, LightBulbIconOutline, } from '../icons';
import { Typography } from '../typography';
/**
 *
 *
 * Helpers
 *
 *
 */
const getStatusIcon = (iconType) => {
    let iconComponent;
    switch (iconType) {
        case 'important':
            iconComponent = (_jsx(ExclamationTriangleIconOutline, { className: "ndl-callout-important-icon" }));
            break;
        case 'example':
            iconComponent = (_jsx(BeakerIconOutline, { className: "ndl-callout-example-icon" }));
            break;
        case 'tip':
            iconComponent = _jsx(LightBulbIconOutline, { className: "ndl-callout-tip-icon" });
            break;
        case 'note':
        default:
            iconComponent = (_jsx(InformationCircleIconOutline, { className: "ndl-callout-note-icon" }));
    }
    return _jsx("div", { className: "ndl-callout-icon", children: iconComponent });
};
/**
 *
 *
 * Callout Component
 *
 *
 */
export const Callout = React.forwardRef(function Callout({ as, type = 'note', header = null, children, description = null, className, style, htmlAttributes, }, ref) {
    const Component = as || 'div';
    const classes = classNames('ndl-callout', className, {
        'ndl-callout-note': type === 'note',
        'ndl-callout-important': type === 'important',
        'ndl-callout-example': type === 'example',
        'ndl-callout-tip': type === 'tip',
    });
    return (_jsxs(Component, Object.assign({ ref: ref, className: classes, style: style }, htmlAttributes, { children: [_jsx("div", { className: "ndl-callout-rectangle" }), _jsxs("div", { className: "ndl-callout-wrapper", children: [getStatusIcon(type), _jsxs("div", { className: "ndl-callout-content", children: [_jsx(Typography, { variant: "h6", className: "ndl-callout-title", children: type.toUpperCase() }), header && (_jsx(Typography, { variant: "subheading-medium", className: "ndl-callout-header", children: header })), (description || children) && (_jsx(Typography, { variant: "body-medium", className: "ndl-callout-description", children: children || description }))] })] })] })));
});
//# sourceMappingURL=Callout.js.map