/**
 *
 *  Copyright (c) "Neo4j"
 *  Neo4j Sweden AB [http://neo4j.com]
 *
 *  This file is part of Neo4j.
 *
 *  Neo4j is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
import type React from 'react';
import { type ComponentPropsWithoutRef } from 'react';
import { type HtmlAttributes } from '../types';
import { type CommonInputProps } from './types';
/**
 *
 *
 * Types
 *
 *
 */
export interface RadioAndCheckboxProps extends Omit<CommonInputProps, 'label'> {
    /** Sets checked state */
    isChecked?: boolean;
    /** Displays label before */
    hasLabelBefore?: boolean;
    label?: string | React.ReactNode;
    isDisabled?: boolean;
    isReadOnly?: boolean;
    isFluid?: boolean;
    onClick?: (event: React.MouseEvent<HTMLInputElement>) => void;
    onChange?: (event: React.ChangeEvent<HTMLInputElement>) => void;
    type?: ComponentPropsWithoutRef<'input'>['type'];
    value?: React.InputHTMLAttributes<HTMLInputElement>['value'];
    ariaLabel?: string;
    isDefaultChecked?: boolean;
    /** HTML attributes */
    htmlAttributes?: HtmlAttributes<'input'>;
    /**
     * Additional classnames will be applied to the root element.
     */
    className?: string;
    /**
     * Additional css styling. Will be applied to the root element.
     */
    style?: React.CSSProperties;
}
/** Add any helper functions here. */
/**
 *
 *
 * Component
 *
 *
 */
export declare const customLabelAndNoAriaLabelWarningMessage = "aria label not detected when using a custom label, be sure to include an aria label for screen readers link: https://dequeuniversity.com/rules/axe/4.2/label?application=axeAPI";
declare const _default: React.ForwardRefExoticComponent<Omit<RadioAndCheckboxProps, "ref"> & React.RefAttributes<HTMLInputElement>>;
export default _default;
