/**
 *
 *  Copyright (c) "Neo4j"
 *  Neo4j Sweden AB [http://neo4j.com]
 *
 *  This file is part of Neo4j.
 *
 *  Neo4j is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
import { type ComponentPropsWithoutRef, type CSSProperties } from 'react';
export type HtmlAttributes<T extends React.ElementType> = ComponentPropsWithoutRef<T> & {
    [key: `data-${string}`]: string | undefined;
};
type PolymorphicProps<T extends React.ElementType, P> = P & {
    /**
     * An override of the default HTML tag of the root of the component.
     * Can also be another React component.
     */
    as?: T;
    /**
     * Html attributes to apply to the root element. This will override any default html attributes, use with caution.
     */
    htmlAttributes?: HtmlAttributes<T>;
    /**
     * Additional classnames will be applied to the root element.
     */
    className?: string;
    /**
     * Additional css styling. Will be applied to the root element.
     */
    style?: CSSProperties;
};
type MergeTypes<T, U> = Omit<T, keyof U> & U;
export type PolymorphicPropsWithRef<T extends React.ElementType, P> = PolymorphicProps<T, P> & {
    ref?: PolymorphicRef<T>;
};
export type PolymorphicPropsWithoutRef<T extends React.ElementType, P> = PolymorphicProps<T, P>;
export type PolymorphicExoticComponent<T extends React.ElementType = React.ElementType, P = Record<string, never>> = MergeTypes<React.ExoticComponent<P & {
    [key: string]: unknown;
}>, {
    <InstanceT extends React.ElementType = T>(props: PolymorphicPropsWithRef<InstanceT, P>): React.ReactElement | null;
}>;
export type PolymorphicForwardRefExoticComponent<T extends React.ElementType, P> = MergeTypes<React.ForwardRefExoticComponent<P & {
    [key: string]: unknown;
}>, PolymorphicExoticComponent<T, P>>;
export type PolymorphicRef<T extends React.ElementType> = React.ComponentPropsWithRef<T>['ref'];
export {};
