/**
 *
 *  Copyright (c) "Neo4j"
 *  Neo4j Sweden AB [http://neo4j.com]
 *
 *  This file is part of Neo4j.
 *
 *  Neo4j is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
import type React from 'react';
import { type HtmlAttributes, type PolymorphicPropsWithoutRef } from '../_common/types';
import { type TypographyVariants } from '../typography';
export type AccordionItemId = string | number | undefined;
export interface AccordionBase {
    /** The component children. */
    children: React.ReactNode;
}
interface IsNotMultiple<T extends AccordionItemId> {
    isMultiple: false | undefined;
    expandedItemId: T | null;
    onChange: (expandedItemId: T | null) => void;
}
interface IsMultiple<T extends AccordionItemId> {
    isMultiple: true;
    expandedItemIds: T[];
    onChange: (expandedItemIds: T[]) => void;
}
type AccordionIsMultiple<T extends AccordionItemId> = AccordionBase & IsMultiple<T>;
type AccordionIsNotMultiple<T extends AccordionItemId> = AccordionBase & IsNotMultiple<T>;
export type AccordionProps<T extends AccordionItemId> = AccordionIsMultiple<T> | AccordionIsNotMultiple<T>;
export type AccordionArrowPosition = 'left' | 'right';
export interface AccordionItemProps<T extends AccordionItemId> {
    /** The component item id. */
    itemId: T;
    /** The title. */
    title: string;
    /** Callback function on component item expand/collapse change. */
    onExpandedChange?: (expanded: boolean) => void;
    /** Which side the accordion arrow will appear. */
    arrowPosition?: AccordionArrowPosition;
    /** If the component item is disabled. */
    isDisabled?: boolean;
    htmlAttributes?: HtmlAttributes<'div'>;
    children?: React.ReactNode;
    className?: string;
    /** The typography variant for the title. */
    titleTypographyVariant?: TypographyVariants;
    /** If the component item has a divider. */
    hasDivider?: boolean;
    /** Content to be displayed on the right side of the title. */
    rightContent?: React.ReactNode;
}
type ClassicItemProps<T extends AccordionItemId> = Omit<AccordionItemProps<T>, 'hasDivider' | 'rightContent' | 'titleTypographyVariant'>;
type CleanItemProps<T extends AccordionItemId> = Omit<AccordionItemProps<T>, 'hasDivider'>;
declare const Accordion: (<T extends AccordionItemId, U extends React.ElementType = "div">(props: PolymorphicPropsWithoutRef<U, AccordionProps<T>> & React.RefAttributes<unknown>) => React.ReactElement | null) & {
    Item: {
        <T extends AccordionItemId, U extends React.ElementType = "div">({ className, ...restProps }: PolymorphicPropsWithoutRef<U, ClassicItemProps<T>>): import("react/jsx-runtime").JSX.Element;
        displayName: string;
    };
    CleanItem: {
        <T extends AccordionItemId, U extends React.ElementType = "div">({ className, ...restProps }: PolymorphicPropsWithoutRef<U, CleanItemProps<T>>): import("react/jsx-runtime").JSX.Element;
        displayName: string;
    };
};
export { Accordion };
