/**
 *
 *  Copyright (c) "Neo4j"
 *  Neo4j Sweden AB [http://neo4j.com]
 *
 *  This file is part of Neo4j.
 *
 *  Neo4j is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
import React from 'react';
import { type PolymorphicForwardRefExoticComponent } from '../_common/types';
import { type ButtonSizes } from '../button';
/**
 *
 *
 * Types
 *
 *
 */
export type IconButtonProps = {
    children: React.ReactNode;
    /** If the icon button is in disabled state */
    isDisabled?: boolean;
    /** If the button is doing something Async, it will display a loading spinner   */
    isLoading?: boolean;
    /** If the button does not have a visible container */
    isClean?: boolean;
    /** Size of button */
    size?: ButtonSizes;
    /** If the button is in floating state */
    isFloating?: boolean;
    /** Turn the button red button */
    isDanger?: boolean;
    /** If the button is in a group, the icon's container is more compact */
    isGrouped?: boolean;
    /** Active - used for open context menus for example */
    isActive?: boolean;
    /** aria-label - {@link https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/Attributes/aria-label} */
    ariaLabel: string;
    onClick?: (e: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void;
    onKeyDown?: (e: React.KeyboardEvent<HTMLButtonElement>) => void;
};
export declare const IconButton: PolymorphicForwardRefExoticComponent<'button', IconButtonProps>;
