/**
 *
 *  Copyright (c) "Neo4j"
 *  Neo4j Sweden AB [http://neo4j.com]
 *
 *  This file is part of Neo4j.
 *
 *  Neo4j is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
import { type RowData, type Table as DataGridType } from '@tanstack/react-table';
import { type HtmlAttributes } from '../_common/types';
import { type SkeletonProps } from '../skeleton';
import { type DataGridComponentsInterface } from './DataGridContext';
export declare const DataGridComponents: {
    ResizingBar: <T extends RowData>({ header, children, innerProps, }: import("./Components").ResizingBarProps<T>) => import("react/jsx-runtime").JSX.Element;
    Header: ({ children, innerProps }: import("./Components").CommonInnerProps<HTMLDivElement>) => import("react/jsx-runtime").JSX.Element;
    Body: ({ children, innerProps }: import("./Components").CommonInnerProps<HTMLDivElement>) => import("react/jsx-runtime").JSX.Element;
    BodyCell: <T extends RowData>({ cell, children, innerProps, }: import("./Components").BodyCellProps<T>) => import("react/jsx-runtime").JSX.Element;
    BodyRow: <T extends RowData>({ row, children, innerProps, }: import("./Components").BodyRowProps<T>) => import("react/jsx-runtime").JSX.Element;
    RowActionCell: <T extends RowData>({ cell, innerIconButtonProps, innerMenuProps, }: import("./Components").RowActionCellProps<T>) => import("react/jsx-runtime").JSX.Element | null;
    InlineEditCell: <T extends RowData>({ cell, value, ariaLabel, }: import("./Components").InlineEditCellProps<T>) => import("react/jsx-runtime").JSX.Element | null;
    DropDownCell: <T extends RowData>({ cell, options, portalTarget: portalTargetProp, ariaLabel, }: import("./Components").DropDownCellProps<T>) => import("react/jsx-runtime").JSX.Element | null;
    HeaderCell: <T extends RowData>({ cell, children, innerProps, }: import("./Components").HeaderCellProps<T>) => import("react/jsx-runtime").JSX.Element;
    HeaderTitle: <T extends RowData>({ cell, children, innerProps, }: import("./Components").HeaderTitleProps<T>) => import("react/jsx-runtime").JSX.Element;
    ActionButton: ({ action, children, onClose, innerProps, }: import("./Components").ActionButtonProps) => import("react/jsx-runtime").JSX.Element;
    ColumnControls: <T extends RowData>({ cell, children, innerProps, }: import("./Components").ColumnControlsProps<T>) => import("react/jsx-runtime").JSX.Element | null;
    Navigation: ({ children, innerProps, }: import("./Components").CommonInnerProps<HTMLDivElement>) => import("react/jsx-runtime").JSX.Element;
    TableResults: ({ children, innerProps, manualPagination, }: import("./Components").TableResultProps) => import("react/jsx-runtime").JSX.Element;
    RowsPerPage: ({ children, innerProps, menuPortalTarget: menuPortalTargetProp, }: import("./Components").RowsPerPageProps) => import("react/jsx-runtime").JSX.Element;
    Pagination: ({ children, innerProps, }: import("./Components").CommonInnerProps<HTMLDivElement>) => import("react/jsx-runtime").JSX.Element;
    PaginationNumericButtons: () => import("react/jsx-runtime").JSX.Element;
    PaginationNumericButton: ({ currentIndex, isSelected, children, innerProps, }: import("./Components").PaginationNumericButtonProps) => import("react/jsx-runtime").JSX.Element;
    PaginationArrowButton: ({ action, children, innerProps, }: import("./Components").PaginationArrowButtonProps) => import("react/jsx-runtime").JSX.Element;
    LoadingPlaceholder: ({ children, innerProps, }: import("./Components").CommonInnerProps<HTMLDivElement>) => import("react/jsx-runtime").JSX.Element;
    NoDataPlaceholder: ({ children, innerProps, }: import("./Components").CommonInnerProps<HTMLDivElement>) => import("react/jsx-runtime").JSX.Element;
    /** @deprecated use NoDataIcon instead */
    NoDataIllustration: (props: import("react").SVGProps<SVGSVGElement>) => import("react/jsx-runtime").JSX.Element;
    NoDataIcon: import("react").ForwardRefExoticComponent<Omit<import("react").SVGProps<SVGSVGElement>, "ref"> & import("react").RefAttributes<SVGSVGElement>>;
    NoDataPlaceholderContentWrapper: ({ children, innerProps, }: import("./Components").CommonInnerProps<HTMLDivElement>) => import("react/jsx-runtime").JSX.Element;
    Scrollable: ({ children, innerProps }: import("./Components").CommonInnerProps) => React.JSX.Element;
};
declare enum BorderStyleEnum {
    AllSides = "all-sides",
    Horizontal = "horizontal",
    Vertical = "vertical",
    None = "none"
}
export type BorderStyle = `${BorderStyleEnum}`;
declare enum HeaderStyleEnum {
    Filled = "filled",
    Clean = "clean"
}
export type HeaderStyle = `${HeaderStyleEnum}`;
export type DataGridProps<T extends RowData> = {
    styling?: Partial<{
        /** Alternate the background color of rows */
        hasZebraStriping: boolean;
        /** Type of border that will be used */
        borderStyle: BorderStyle;
        /** If header should have styles or not (Aura example) */
        headerStyle: HeaderStyle;
        /** If background hover effects should be enabled on rows and header cells */
        hasHoverEffects: boolean;
    }>;
    /** Resizing the width of columns */
    isResizable?: boolean;
    /** Enables table's loading state */
    isLoading?: boolean;
    /**
     * Enables keyboard navigation.
     * To control keyboard navigation programmatically
     * for edge cases, pass a `ref` to `tableNavRef`
     */
    isKeyboardNavigable?: boolean;
    /**
     * Enables automatic resizing of columns.
     * If `isResizable` is `true`, the columns will only be automatically resized on initial render of the table.
     * If `isResizable` is `false`, the columns will be resized automatically to always fit the table width (assuming that column maxWidths allow for it).
     * Note: Action columns are a fixed size of 40px, and Pinned columns are not resized automatically.
     * @defaultValue true
     */
    isAutoResizingColumns?: boolean;
    /**
     * Reference to the tableNav instance
     * for programmatic control
     */
    tableNavRef?: React.RefObject<any>;
    /** Table instance created from `useTable`*/
    tableInstance: DataGridType<T>;
    /** Table sub-component overrides */
    components?: DataGridComponentsInterface<T>;
    /** Root `div` props */
    rootProps?: HtmlAttributes<'div'>;
    isSkeletonLoading?: boolean;
    skeletonProps?: SkeletonProps;
    /** The target element for portaled elements to be rendered in, e.g. the modal root if the data grid is inside a modal.
     * This is used in for example the DropdownCell, RowsPerPage, and ColumnControls.
     */
    portalTarget?: HTMLElement | null;
};
export declare const DataGrid: <T extends RowData>(props: DataGridProps<T> & import("react").RefAttributes<HTMLDivElement>) => import("react").ReactElement | null;
export {};
