/**
 *
 *  Copyright (c) "Neo4j"
 *  Neo4j Sweden AB [http://neo4j.com]
 *
 *  This file is part of Neo4j.
 *
 *  Neo4j is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
import '@tanstack/react-table';
import { type CellContext, type RowData } from '@tanstack/react-table';
import { type MenuItemProps, type NestedMenuItemProps } from '../context-menu';
export type ColumnAction = MenuItemProps;
export type RowAction = MenuItemProps;
declare module '@tanstack/react-table' {
    interface ColumnMeta<TData extends RowData, TValue> {
        columnActions?: {
            /**
             * Prepends two default sorting actions to the column.
             * Should be disabled for columns that are sorted on server side.
             */
            hasDefaultSortingActions?: boolean;
            /** Column actions that will be rendered in order */
            actions?: ColumnAction[];
            /** Callback for consumer to delegate task like polling */
            onOpenChange?: (isOpen: boolean) => void;
        };
        /** If the column is an action column, including action array is mandatory */
        isActionCell?: {
            /** Column actions that will be rendered in order */
            actions: ({
                onClick?: (event: React.MouseEvent<HTMLElement, MouseEvent> | React.KeyboardEvent<HTMLElement>, cell: CellContext<TData, TValue>) => void;
            } & (Omit<NestedMenuItemProps, 'onClick'> | Omit<MenuItemProps, 'onClick'>))[];
            /** Callback for consumer to delegate tasks like polling */
            onOpenChange?: (isOpen: boolean) => void;
        };
        isInlineEditCell?: {
            onEditChange: (newValue: string, cell: CellContext<TData, TValue>) => void;
        };
        isDropDownCell?: {
            onChange: (newValue: string | undefined, cell: CellContext<TData, TValue>) => void;
        };
    }
}
