/**
 *
 *  Copyright (c) "Neo4j"
 *  Neo4j Sweden AB [http://neo4j.com]
 *
 *  This file is part of Neo4j.
 *
 *  Neo4j is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import { type DropzoneOptions } from 'react-dropzone';
import { type HtmlAttributes } from '../_common/types';
/**
 *
 *
 * Types
 *
 *
 */
export interface DropzoneProps {
    /**
     *  See here - https://react-dropzone.js.org/#src. Don't use 'accept'
     *  if using custom file extensions as this option is broken.
     *  Instead use the acceptedFileExtensions property.
     */
    dropZoneOptions: DropzoneOptions;
    /** Supported file text in the footer */
    supportedFilesDescription?: React.ReactNode | string;
    /** Element to display when uploading the file. When passed, drag&drop zone is disabled */
    loadingComponent?: React.ReactNode | string;
    /** To be used when want to test loadingComponent UI without actually dragging and uploading the files */
    isTesting?: boolean;
    /** Use when wanting a custom title. */
    customTitle?: React.ReactNode | string;
    /** Message to be shown when file is rejected. */
    rejectedMessage?: React.ReactNode | string;
    /** The accepted file extensions for the Drag-and-Drop. */
    acceptedFileExtensions?: string[];
    /** HTML attributes */
    htmlAttributes?: HtmlAttributes<'div'>;
    /** classNames */
    className?: string;
    /** Extra styles */
    style?: React.CSSProperties;
}
export interface DropzoneLoadingProgressBarProps {
    /**  The percentage of the progress bar. */
    progressBarPrecentage: number;
    /** The time in minute left to upload the file. */
    progressBarMinute?: number;
    /** HTML attributes */
    htmlAttributes?: HtmlAttributes<'div'>;
}
declare const Dropzone: ((props: DropzoneProps) => import("react/jsx-runtime").JSX.Element) & {
    LoadingProgressBar: (props: DropzoneLoadingProgressBarProps) => import("react/jsx-runtime").JSX.Element;
};
export { Dropzone };
