/**
 *
 *  Copyright (c) "Neo4j"
 *  Neo4j Sweden AB [http://neo4j.com]
 *
 *  This file is part of Neo4j.
 *
 *  Neo4j is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
import React from 'react';
import { type HtmlAttributes } from '../_common/types';
export declare enum ModalCloseReason {
    BACKDROP_CLICK = "backdropClick",
    ESCAPE_KEY_DOWN = "escapeKeyDown"
}
export interface ModalProps {
    isOpen: boolean;
    children: React.ReactNode;
    /**
     * We provide convenient default sizes for the modal,
     * but you can also set your own size, when providing
     * `unset` to the `size` prop.
     */
    size?: 'small' | 'medium' | 'large' | 'unset';
    container?: Element;
    onClose?: (e: React.MouseEvent<HTMLElement> | React.KeyboardEvent<HTMLElement>, reason?: ModalCloseReason) => void;
    /** Forwards the props to the modal container's wrapper - use with caution */
    rootProps?: HtmlAttributes<'div'>;
    /** Forwards the props to the modal container */
    modalProps?: HtmlAttributes<'div'>;
    /** HTML attributes */
    htmlAttributes?: HtmlAttributes<'div'>;
}
export declare const Modal: React.ForwardRefExoticComponent<ModalProps & React.RefAttributes<HTMLDivElement>>;
