/**
 *
 *  Copyright (c) "Neo4j"
 *  Neo4j Sweden AB [http://neo4j.com]
 *
 *  This file is part of Neo4j.
 *
 *  Neo4j is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import { type HtmlAttributes, type PolymorphicForwardRefExoticComponent } from '../_common/types';
export interface SliderPropsBase {
    /** Forwards the props to the slider container's wrapper */
    /** Forwards the input element(s) of the slider */
    inputProps?: HtmlAttributes<'input'>;
    /**
     * Which value interval will be added or removed from
     * the current value when moving the slider button.
     *
     * @default 1
     */
    step?: number;
    isDisabled?: boolean;
    /**
     * The minimum value possible to choose.
     * @default 0
     */
    minValue?: number;
    /**
     * The maximum value possible to choose.
     * @default 100
     */
    maxValue?: number;
    /**
     * Displays a tooltip with the current
     * value for a brief second.
     */
    showValues?: boolean;
    /**
     * Displays visual indicators for each
     * of the steps in the slider.
     */
    showSteps?: boolean;
    /** HTML attributes */
    htmlAttributes?: HtmlAttributes<'div'>;
    /** Additional classnames */
    className?: string;
}
type SingleSlider = SliderPropsBase & {
    type?: 'single' | undefined;
    /**
     * Current value of the single slider.
     */
    value: number;
    onChange: (value: number) => void;
};
type RangeSlider = SliderPropsBase & {
    type: 'range';
    /**
     * Current values of the range slider.
     */
    values: [number, number];
    onChange: (value: [number, number]) => void;
    className?: string;
};
export type SliderProps = SingleSlider | RangeSlider;
export declare const Slider: PolymorphicForwardRefExoticComponent<'div', SliderProps>;
export {};
