/**
 *
 *  Copyright (c) "Neo4j"
 *  Neo4j Sweden AB [http://neo4j.com]
 *
 *  This file is part of Neo4j.
 *
 *  Neo4j is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import type React from 'react';
type SpotlightContextType = {
    /** Is true if the spotlight is open */
    isOpen: boolean;
    /** Closes or opens the spotlight */
    setIsOpen: (arg: boolean) => void;
    /** Is true if the provided target is the active spotlight */
    isActiveSpotlight: (target: string) => boolean;
    /** Sets the active spotlight to the provided target. Use null to clear active target */
    setActiveSpotlight: (target: string | null) => void;
    registerTarget: (id: string, ref: React.RefObject<HTMLElement>) => void;
    unregisterTarget: (id: string) => void;
    registeredTargets: Record<string, React.RefObject<HTMLElement>>;
    /** If the spotlights should have an overlay */
    hasOverlay?: boolean;
};
export declare const useSpotlightContext: () => SpotlightContextType;
type SpotlightProviderProps = {
    children: React.ReactNode;
    /** If the spotlights should have an overlay */
    hasOverlay?: boolean;
    /** If the overlay should be transparent */
    isOverlayTransparent?: boolean;
};
export declare const SpotlightProvider: ({ children, hasOverlay, isOverlayTransparent, }: SpotlightProviderProps) => import("react/jsx-runtime").JSX.Element;
export {};
