/**
 *
 *  Copyright (c) "Neo4j"
 *  Neo4j Sweden AB [http://neo4j.com]
 *
 *  This file is part of Neo4j.
 *
 *  Neo4j is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
import type React from 'react';
import { type ReactNode } from 'react';
import { type TooltipObjectProps } from '../_common/input/types';
import { type HtmlAttributes } from '../_common/types';
/**
 *
 *
 * Types
 *
 *
 */
export interface TextAreaProps {
    /** Label text */
    label?: ReactNode;
    /** Displays with fluid width */
    isFluid?: boolean;
    /** Help message */
    helpText?: string | ReactNode;
    /** Error message */
    errorText?: string | ReactNode;
    /** Size of the textArea */
    size?: 'small' | 'medium' | 'large';
    /** If the component is optional to fill in */
    isOptional?: boolean;
    /** Information to be displayed in the information tooltip */
    informationIconText?: React.ReactNode;
    /** Pass props to the underlying Tip component */
    tooltipProps?: TooltipObjectProps;
    isDisabled?: boolean;
    /** HTML attributes */
    htmlAttributes?: HtmlAttributes<'textarea'>;
    ariaLabel?: string;
    /**
     * Additional classnames will be applied to the root element.
     */
    className?: string;
    /**
     * Additional css styling. Will be applied to the root element.
     */
    style?: React.CSSProperties;
    isReadOnly?: boolean;
    value?: React.ComponentPropsWithoutRef<'textarea'>['value'];
    placeholder?: React.ComponentPropsWithoutRef<'textarea'>['placeholder'];
}
/**
 *
 *
 * TextArea Component
 *
 *
 */
export declare const TextArea: React.ForwardRefExoticComponent<TextAreaProps & React.RefAttributes<HTMLTextAreaElement>>;
