/**
 *
 *  Copyright (c) "Neo4j"
 *  Neo4j Sweden AB [http://neo4j.com]
 *
 *  This file is part of Neo4j.
 *
 *  Neo4j is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
import { type ReactElement, type ReactNode } from 'react';
import { type TooltipObjectProps } from '../_common/input/types';
import { type HtmlAttributes } from '../_common/types';
import { type SkeletonProps } from '../skeleton';
export interface TextInputProps {
    helpText?: string | ReactNode;
    /** Error message */
    errorText?: string | ReactNode;
    /** Element to be shown as left icon */
    leftElement?: ReactElement;
    /** Element to be shown as right icon */
    rightElement?: ReactElement;
    /** Size of the input field */
    size?: 'small' | 'medium' | 'large';
    /** Whether the input field is readonly */
    isReadOnly?: boolean;
    /** If the component is optional to fill in */
    isOptional?: boolean;
    isDisabled?: boolean;
    isRequired?: boolean;
    value?: React.ComponentPropsWithoutRef<'input'>['value'];
    placeholder?: React.ComponentPropsWithoutRef<'input'>['placeholder'];
    onChange?: React.ComponentPropsWithoutRef<'input'>['onChange'];
    /** Displays with fluid width */
    isFluid?: boolean;
    /** Information to be displayed in the information tooltip */
    informationIconText?: React.ReactNode;
    /** Sets the label */
    label?: string | React.ReactNode;
    /** Classname to the `input` element */
    className?: string;
    style?: React.CSSProperties;
    /** Pass props to the underlying Tip component */
    tooltipProps?: TooltipObjectProps;
    htmlAttributes?: HtmlAttributes<'input'>;
    isSkeletonLoading?: boolean;
    skeletonProps?: SkeletonProps;
}
/**
 *
 *
 * TextInput Component
 *
 *
 */
export declare const TextInput: import("react").ForwardRefExoticComponent<TextInputProps & import("react").RefAttributes<HTMLInputElement>>;
