/**
 *
 *  Copyright (c) "Neo4j"
 *  Neo4j Sweden AB [http://neo4j.com]
 *
 *  This file is part of Neo4j.
 *
 *  Neo4j is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
import { type Placement } from '@floating-ui/react';
import type React from 'react';
import { type CSSProperties } from 'react';
import { type HtmlAttributes } from '../_common/types';
import { Typography } from '../typography';
export interface TooltipProps {
    children: React.ReactNode;
    isDisabled?: boolean;
    isInitialOpen?: boolean;
    placement?: Placement;
    isOpen?: boolean;
    type: 'simple' | 'rich';
    isPortaled?: boolean;
    onOpenChange?: (open: boolean) => void;
    strategy?: 'absolute' | 'fixed';
    hoverDelay?: {
        open: number;
        close: number;
    };
}
export declare function Tooltip({ children, isDisabled, type, isInitialOpen, placement, isOpen, onOpenChange, isPortaled, strategy: strategyProp, hoverDelay, }: TooltipProps): import("react/jsx-runtime").JSX.Element;
export declare namespace Tooltip {
    var Content: React.ForwardRefExoticComponent<TooltipContentProps & React.RefAttributes<HTMLDivElement>>;
    var Trigger: React.ForwardRefExoticComponent<TooltipTriggerProps & React.RefAttributes<HTMLElement>>;
    var Header: ({ children, className, passThroughProps, }: TooltipHeaderProps) => import("react/jsx-runtime").JSX.Element | null;
    var Body: ({ children, className, passThroughProps, }: TooltipBodyProps) => import("react/jsx-runtime").JSX.Element | null;
    var Actions: React.ForwardRefExoticComponent<ToolTipActionsProps & React.RefAttributes<HTMLDivElement>>;
    var Action: ({ children, className, onClick, htmlAttributes, variant, }: TooltipActionProps) => import("react/jsx-runtime").JSX.Element | null;
    var ActionClose: React.ForwardRefExoticComponent<TooltipActionCloseProps & React.RefAttributes<HTMLButtonElement>>;
}
export interface TooltipTriggerProps {
    children: React.ReactNode;
    hasButtonWrapper?: boolean;
    className?: string;
    htmlAttributes?: HtmlAttributes<'button'>;
}
export interface TooltipContentProps {
    children: React.ReactNode;
    className?: string;
    style?: CSSProperties;
    htmlAttributes?: HtmlAttributes<'div'>;
}
export type TooltipHeaderProps = {
    children: React.ReactNode;
    className?: string;
    passThroughProps?: Partial<React.ComponentPropsWithoutRef<typeof Typography>>;
};
export type TooltipBodyProps = {
    children: React.ReactNode;
    className?: string;
    passThroughProps?: Partial<React.ComponentPropsWithoutRef<typeof Typography>>;
};
export interface ToolTipActionsProps {
    children: React.ReactNode;
    className?: string;
    htmlAttributes?: HtmlAttributes<'div'>;
}
export type TooltipActionProps = {
    children: React.ReactNode;
    className?: string;
    onClick?: () => void;
    htmlAttributes?: HtmlAttributes<'button'>;
    variant?: 'outlined' | 'text' | 'underlined';
};
export type TooltipActionCloseProps = {
    className?: string;
    htmlAttributes?: HtmlAttributes<'button'>;
};
