/**
 *
 *  Copyright (c) "Neo4j"
 *  Neo4j Sweden AB [http://neo4j.com]
 *
 *  This file is part of Neo4j.
 *
 *  Neo4j is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
import { type UniqueIdentifier } from '@dnd-kit/core';
import { type UseSortableArguments } from '@dnd-kit/sortable';
import { type FlattenedTreeItem, type ItemChangedReason, type TreeItemComponent } from './tree-view-types';
export interface TreeItemProps<T> {
    childCount?: number;
    clone?: boolean;
    collapsed?: boolean;
    depth: number;
    shouldDisableInteraction?: boolean;
    indicator?: boolean;
    indentationWidth: number;
    item: FlattenedTreeItem<T>;
    isLast: boolean;
    parent: FlattenedTreeItem<T> | null;
    onCollapse?(id: UniqueIdentifier): void;
    onRemove?(id: UniqueIdentifier): void;
    wrapperRef?(node: HTMLLIElement): void;
}
type SortableTreeItemProps<T extends Record<string, unknown>, E extends HTMLElement> = TreeItemProps<T> & {
    id: UniqueIdentifier;
    TreeItemComponent: TreeItemComponent<T, E>;
    shouldDisableSorting?: boolean;
    sortableProps?: Omit<UseSortableArguments, 'id'>;
    keepGhostInPlace?: boolean;
    trails: ('none' | 'straight' | 'straight-curved' | 'curved')[];
    onItemsChanged: (newItems: FlattenedTreeItem<T>[], itemChangedReason: ItemChangedReason<T>) => void;
    items: FlattenedTreeItem<T>[];
    tabIndex?: number;
    onFocus?: () => void;
};
declare const SortableTreeViewItemNotMemoized: <T extends Record<string, unknown>, E extends HTMLElement>({ id, depth, isLast, TreeItemComponent, parent, shouldDisableSorting, sortableProps, keepGhostInPlace, item, onCollapse, trails, onItemsChanged, items, tabIndex, onFocus, ...restProps }: SortableTreeItemProps<T, E>) => import("react/jsx-runtime").JSX.Element;
export declare const SortableTreeViewItem: typeof SortableTreeViewItemNotMemoized;
export {};
