/**
 *
 *  Copyright (c) "Neo4j"
 *  Neo4j Sweden AB [http://neo4j.com]
 *
 *  This file is part of Neo4j.
 *
 *  Neo4j is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
import { type tokens } from '@neo4j-ndl/base';
export type TypographyVariants = keyof typeof tokens.font.size;
export declare const TypographyDefaultMapping: {
    readonly h1: "h1";
    readonly h2: "h2";
    readonly h3: "h3";
    readonly h4: "h4";
    readonly h5: "h5";
    readonly h6: "h6";
    readonly 'subheading-large': "span";
    readonly 'subheading-medium': "span";
    readonly 'subheading-small': "span";
    readonly 'body-large': "span";
    readonly 'body-medium': "span";
    readonly 'body-small': "span";
    readonly code: "code";
    readonly label: "span";
};
type Tags = keyof HTMLElementTagNameMap;
type VariantsDefaultType<T extends TypographyVariants> = Omit<React.ComponentPropsWithoutRef<(typeof TypographyDefaultMapping)[T]>, 'as'> & {
    variant: TypographyVariants;
};
export type ReactComponent = (args: any) => React.JSX.Element;
export type AsType = undefined | Tags | React.FunctionComponent<any>;
export type ConditionalTypography<T extends AsType, V extends TypographyVariants> = T extends undefined ? VariantsDefaultType<V> : T extends Tags ? React.ComponentPropsWithoutRef<T> : T extends ReactComponent ? React.ComponentProps<T> : never;
export {};
